diff --git a/MatterControl.csproj b/MatterControl.csproj
index 25aa2ad4c..3d864224f 100644
--- a/MatterControl.csproj
+++ b/MatterControl.csproj
@@ -397,10 +397,6 @@
{3DF4CB3D-9A03-4256-9A81-70523AAD828B}
Launcher
-
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}
- InfInstaller
-
{C958F745-156E-4BDC-A24A-3721C7BE7B8A}
OpenGlGui
diff --git a/MatterControl.sln b/MatterControl.sln
index 73c2451d0..9740fd76e 100644
--- a/MatterControl.sln
+++ b/MatterControl.sln
@@ -1,6 +1,8 @@
-Microsoft Visual Studio Solution File, Format Version 11.00
-# Visual Studio 2010
+Microsoft Visual Studio Solution File, Format Version 12.00
+# Visual Studio 2013
+VisualStudioVersion = 12.0.31101.0
+MinimumVisualStudioVersion = 10.0.40219.1
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "MatterControl", "MatterControl.csproj", "{0B8D6F56-BD7F-4426-B858-D9292B084656}"
ProjectSection(ProjectDependencies) = postProject
{F67AE800-B0C7-42A8-836F-597B4E74591C} = {F67AE800-B0C7-42A8-836F-597B4E74591C}
@@ -23,7 +25,6 @@ Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "MatterControl", "MatterCont
{036BCCBA-52D8-457C-84AE-8821F209FE4A} = {036BCCBA-52D8-457C-84AE-8821F209FE4A}
{7E61A5BD-E78F-4B80-88C9-3821B4FA062E} = {7E61A5BD-E78F-4B80-88C9-3821B4FA062E}
{DF6845CD-64C6-4263-8357-DA8066855739} = {DF6845CD-64C6-4263-8357-DA8066855739}
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9} = {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}
{1E01ABE0-B494-4FE4-B0D6-540133286887} = {1E01ABE0-B494-4FE4-B0D6-540133286887}
{86F6AAF2-9B50-40B8-A427-1897D76471C5} = {86F6AAF2-9B50-40B8-A427-1897D76471C5}
{670BDDFF-927B-425D-9DD1-22ACB14356EB} = {670BDDFF-927B-425D-9DD1-22ACB14356EB}
@@ -60,8 +61,6 @@ Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "GCodeVisualizer", "..\agg-s
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "SerialPortCommunication", "..\agg-sharp\SerialPortCommunication\SerialPortCommunication.csproj", "{D3ABF72C-64C2-4E51-A119-E077210FA990}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "InfInstaller", "PrinterDriverInstaller\InfInstaller.csproj", "{990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}"
-EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "MeshViewer", "..\agg-sharp\examples\MeshViewer\MeshViewer.csproj", "{A737BC76-165B-46C6-82B7-8871C7C92942}"
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Localizations", "..\agg-sharp\Localizations\Localizations.csproj", "{CA96058C-1A37-465D-A357-D6D695B13D25}"
@@ -90,8 +89,6 @@ Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "MatterControlAuth", "..\Mat
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "PictureCreator", "..\MatterControlPictureCreator\PictureCreator\PictureCreator.csproj", "{BEC6FD13-C765-4B90-836B-53823AC12E20}"
EndProject
-Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "X3GCommunication", "..\MatterControlX3GCommunication\X3GCommunication.csproj", "{A3680C51-A549-4D1F-AEA5-3931EA755E9A}"
-EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "PlatformAbstract", "..\agg-sharp\PlatformAbstract\PlatformAbstract.csproj", "{3E4AABA8-D85F-4922-88C6-5C1B2D2308FB}"
EndProject
Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "CloudServices", "..\CloudServicesPlugin\CloudServices\CloudServices.csproj", "{6782BF37-8139-4DC6-885E-98D22D1FB258}"
@@ -367,25 +364,6 @@ Global
{D3ABF72C-64C2-4E51-A119-E077210FA990}.Release64|x64.ActiveCfg = Release64|Any CPU
{D3ABF72C-64C2-4E51-A119-E077210FA990}.Release64|x64.Build.0 = Release64|Any CPU
{D3ABF72C-64C2-4E51-A119-E077210FA990}.Release64|x86.ActiveCfg = Release64|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug|Any CPU.Build.0 = Debug|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug|x64.ActiveCfg = Debug|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug|x64.Build.0 = Debug|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug|x86.ActiveCfg = Debug|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug64|Any CPU.ActiveCfg = Debug64|x64
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug64|Any CPU.Build.0 = Debug64|x64
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug64|x64.ActiveCfg = Debug64|x64
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug64|x64.Build.0 = Debug64|x64
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Debug64|x86.ActiveCfg = Debug64|x64
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release|Any CPU.ActiveCfg = Release|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release|Any CPU.Build.0 = Release|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release|x64.ActiveCfg = Release|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release|x86.ActiveCfg = Release|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release64|Any CPU.ActiveCfg = Release64|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release64|Any CPU.Build.0 = Release64|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release64|x64.ActiveCfg = Release64|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release64|x64.Build.0 = Release64|Any CPU
- {990A9AD3-B6A4-407B-9DFC-9C722AF7C9B9}.Release64|x86.ActiveCfg = Release64|Any CPU
{A737BC76-165B-46C6-82B7-8871C7C92942}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
{A737BC76-165B-46C6-82B7-8871C7C92942}.Debug|Any CPU.Build.0 = Debug|Any CPU
{A737BC76-165B-46C6-82B7-8871C7C92942}.Debug|x64.ActiveCfg = Debug|Any CPU
@@ -615,23 +593,6 @@ Global
{BEC6FD13-C765-4B90-836B-53823AC12E20}.Release64|Any CPU.Build.0 = Release64|Any CPU
{BEC6FD13-C765-4B90-836B-53823AC12E20}.Release64|x64.ActiveCfg = Release64|Any CPU
{BEC6FD13-C765-4B90-836B-53823AC12E20}.Release64|x86.ActiveCfg = Release64|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug|Any CPU.Build.0 = Debug|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug|x64.ActiveCfg = Debug|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug|x86.ActiveCfg = Debug|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug64|Any CPU.ActiveCfg = Debug64|x64
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug64|Any CPU.Build.0 = Debug64|x64
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug64|x64.ActiveCfg = Debug64|x64
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug64|x64.Build.0 = Debug64|x64
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Debug64|x86.ActiveCfg = Debug64|x64
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release|Any CPU.ActiveCfg = Release|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release|Any CPU.Build.0 = Release|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release|x64.ActiveCfg = Release|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release|x86.ActiveCfg = Release|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release64|Any CPU.ActiveCfg = Release64|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release64|Any CPU.Build.0 = Release64|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release64|x64.ActiveCfg = Release64|Any CPU
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A}.Release64|x86.ActiveCfg = Release64|Any CPU
{3E4AABA8-D85F-4922-88C6-5C1B2D2308FB}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
{3E4AABA8-D85F-4922-88C6-5C1B2D2308FB}.Debug|Any CPU.Build.0 = Debug|Any CPU
{3E4AABA8-D85F-4922-88C6-5C1B2D2308FB}.Debug|x64.ActiveCfg = Debug|Any CPU
@@ -671,6 +632,7 @@ Global
HideSolutionNode = FALSE
EndGlobalSection
GlobalSection(NestedProjects) = preSolution
+ {AE37DE1F-22F7-49EE-8732-FC6BC8DC58D9} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{670BDDFF-927B-425D-9DD1-22ACB14356EB} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{D3E41B4E-BFBB-44CA-94C8-95C00F754FDD} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{545B6912-77FF-4B34-BA76-6C3D6A32BE6A} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
@@ -686,14 +648,12 @@ Global
{036BCCBA-52D8-457C-84AE-8821F209FE4A} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{9B062971-A88E-4A3D-B3C9-12B78D15FA66} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{DF6845CD-64C6-4263-8357-DA8066855739} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
- {A526DC5D-65F3-461B-805F-D3AC9665F5C9} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
- {3E4AABA8-D85F-4922-88C6-5C1B2D2308FB} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
- {AE37DE1F-22F7-49EE-8732-FC6BC8DC58D9} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{291CD87C-2C58-4369-9D85-238C7EB31542} = {DA2BE4E5-5FB2-4C74-9170-0D2513AAFC84}
+ {A526DC5D-65F3-461B-805F-D3AC9665F5C9} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{F49EC1DD-D645-4709-8667-B57318AF67B0} = {DA2BE4E5-5FB2-4C74-9170-0D2513AAFC84}
{239CC6B1-537C-4998-9AA9-3372A3464498} = {DA2BE4E5-5FB2-4C74-9170-0D2513AAFC84}
{BEC6FD13-C765-4B90-836B-53823AC12E20} = {DA2BE4E5-5FB2-4C74-9170-0D2513AAFC84}
- {A3680C51-A549-4D1F-AEA5-3931EA755E9A} = {DA2BE4E5-5FB2-4C74-9170-0D2513AAFC84}
+ {3E4AABA8-D85F-4922-88C6-5C1B2D2308FB} = {2AB9B589-5C98-4C05-BBEA-F97DAE168EAB}
{6782BF37-8139-4DC6-885E-98D22D1FB258} = {DA2BE4E5-5FB2-4C74-9170-0D2513AAFC84}
EndGlobalSection
GlobalSection(MonoDevelopProperties) = preSolution
diff --git a/PrinterControls/PrinterConnections/SetupStepMakeModelName.cs b/PrinterControls/PrinterConnections/SetupStepMakeModelName.cs
index d86f60eaf..86d08a9a2 100644
--- a/PrinterControls/PrinterConnections/SetupStepMakeModelName.cs
+++ b/PrinterControls/PrinterConnections/SetupStepMakeModelName.cs
@@ -260,7 +260,7 @@ namespace MatterHackers.MatterControl.PrinterControls.PrinterConnections
//Determine what if any drivers are needed
if (settingsDict.TryGetValue("windows_driver", out driverFile))
{
- string infPathAndFileToInstall = Path.Combine(ApplicationDataStorage.Instance.ApplicationStaticDataPath, "Drivers", driverFile);
+ string infPathAndFileToInstall = Path.Combine(ApplicationDataStorage.Instance.ApplicationStaticDataPath, "Drivers", Path.GetFileNameWithoutExtension(driverFile), driverFile);
switch (OsInformation.OperatingSystem)
{
case OSType.Windows:
diff --git a/StaticData/Drivers/RAMBo.inf b/StaticData/Drivers/RAMBo/RAMBo.inf
similarity index 98%
rename from StaticData/Drivers/RAMBo.inf
rename to StaticData/Drivers/RAMBo/RAMBo.inf
index 0bee42144..e7c4f25eb 100644
--- a/StaticData/Drivers/RAMBo.inf
+++ b/StaticData/Drivers/RAMBo/RAMBo.inf
@@ -10,7 +10,7 @@ ClassGuid={4D36E978-E325-11CE-BFC1-08002BE10318}
Provider=%MFGNAME%
LayoutFile=layout.inf
CatalogFile=%MFGFILENAME%.cat
-DriverVer=11/15/2007,5.1.2600.0
+DriverVer=04/27/2012,5.1.2600.0
[Manufacturer]
%MFGNAME%=DeviceList, NTamd64
diff --git a/StaticData/Drivers/RAMBo/cdc_vista.cat b/StaticData/Drivers/RAMBo/cdc_vista.cat
new file mode 100644
index 000000000..7891a9722
Binary files /dev/null and b/StaticData/Drivers/RAMBo/cdc_vista.cat differ
diff --git a/StaticData/PrinterSettings/Airwolf 3D/HD/setup.ini b/StaticData/PrinterSettings/Airwolf 3D/HD/setup.ini
index 7b16c2eed..630457893 100644
--- a/StaticData/PrinterSettings/Airwolf 3D/HD/setup.ini
+++ b/StaticData/PrinterSettings/Airwolf 3D/HD/setup.ini
@@ -1,4 +1,5 @@
baud_rate = 250000
default_material_presets = ABS
default_quality_preset = Balanced
+windows_driver = RAMBo.inf
default_macros = Lights On, Lights Off
diff --git a/StaticData/PrinterSettings/Airwolf 3D/HD2x/setup.ini b/StaticData/PrinterSettings/Airwolf 3D/HD2x/setup.ini
index 7b16c2eed..630457893 100644
--- a/StaticData/PrinterSettings/Airwolf 3D/HD2x/setup.ini
+++ b/StaticData/PrinterSettings/Airwolf 3D/HD2x/setup.ini
@@ -1,4 +1,5 @@
baud_rate = 250000
default_material_presets = ABS
default_quality_preset = Balanced
+windows_driver = RAMBo.inf
default_macros = Lights On, Lights Off
diff --git a/StaticData/PrinterSettings/Airwolf 3D/HDL/setup.ini b/StaticData/PrinterSettings/Airwolf 3D/HDL/setup.ini
index dab72ca1e..a8eed77f4 100644
--- a/StaticData/PrinterSettings/Airwolf 3D/HDL/setup.ini
+++ b/StaticData/PrinterSettings/Airwolf 3D/HDL/setup.ini
@@ -1,4 +1,5 @@
baud_rate = 250000
default_material_presets = PLA
+windows_driver = RAMBo.inf
default_quality_preset = Balanced
default_macros = Lights On, Lights Off
diff --git a/StaticData/PrinterSettings/Airwolf 3D/HDx/setup.ini b/StaticData/PrinterSettings/Airwolf 3D/HDx/setup.ini
index 7b16c2eed..630457893 100644
--- a/StaticData/PrinterSettings/Airwolf 3D/HDx/setup.ini
+++ b/StaticData/PrinterSettings/Airwolf 3D/HDx/setup.ini
@@ -1,4 +1,5 @@
baud_rate = 250000
default_material_presets = ABS
default_quality_preset = Balanced
+windows_driver = RAMBo.inf
default_macros = Lights On, Lights Off
diff --git a/StaticData/PrinterSettings/Airwolf 3D/XL/setup.ini b/StaticData/PrinterSettings/Airwolf 3D/XL/setup.ini
index 8daab75df..ad2c9ccde 100644
--- a/StaticData/PrinterSettings/Airwolf 3D/XL/setup.ini
+++ b/StaticData/PrinterSettings/Airwolf 3D/XL/setup.ini
@@ -1,2 +1,3 @@
baud_rate = 250000
+windows_driver = RAMBo.inf
default_material_presets = ABS
diff --git a/StaticData/PrinterSettings/Lulzbot/TAZ 4/setup.ini b/StaticData/PrinterSettings/Lulzbot/TAZ 4/setup.ini
index b0177f650..40f6f0f8f 100644
--- a/StaticData/PrinterSettings/Lulzbot/TAZ 4/setup.ini
+++ b/StaticData/PrinterSettings/Lulzbot/TAZ 4/setup.ini
@@ -1,2 +1,3 @@
baud_rate = 115200
-default_material_presets = ABS
\ No newline at end of file
+default_material_presets = ABS
+windows_driver = RAMBo.inf
diff --git a/StaticData/PrinterSettings/Lulzbot/TAZ/setup.ini b/StaticData/PrinterSettings/Lulzbot/TAZ/setup.ini
index c7337fff1..e301888a3 100644
--- a/StaticData/PrinterSettings/Lulzbot/TAZ/setup.ini
+++ b/StaticData/PrinterSettings/Lulzbot/TAZ/setup.ini
@@ -1,2 +1,3 @@
baud_rate = 115200
-default_material_presets = PLA
\ No newline at end of file
+default_material_presets = PLA
+windows_driver = RAMBo.inf
diff --git a/StaticData/PrinterSettings/SeeMeCNC/Orion/setup.ini b/StaticData/PrinterSettings/SeeMeCNC/Orion/setup.ini
index 5f3491244..cad74b440 100644
--- a/StaticData/PrinterSettings/SeeMeCNC/Orion/setup.ini
+++ b/StaticData/PrinterSettings/SeeMeCNC/Orion/setup.ini
@@ -1,3 +1,4 @@
baud_rate = 250000
default_material_presets = PLA
+windows_driver = RAMBo.inf
default_movement_speeds = x,3000,y,3000,z,3000,e0,3000
\ No newline at end of file
diff --git a/StaticData/PrinterSettings/SeeMeCNC/RostockMAX/setup.ini b/StaticData/PrinterSettings/SeeMeCNC/RostockMAX/setup.ini
index 5f3491244..cad74b440 100644
--- a/StaticData/PrinterSettings/SeeMeCNC/RostockMAX/setup.ini
+++ b/StaticData/PrinterSettings/SeeMeCNC/RostockMAX/setup.ini
@@ -1,3 +1,4 @@
baud_rate = 250000
default_material_presets = PLA
+windows_driver = RAMBo.inf
default_movement_speeds = x,3000,y,3000,z,3000,e0,3000
\ No newline at end of file
diff --git a/StaticData/Translations/pl/Translation.txt b/StaticData/Translations/pl/Translation.txt
index e4e4dcd0e..2bda06ef8 100644
--- a/StaticData/Translations/pl/Translation.txt
+++ b/StaticData/Translations/pl/Translation.txt
@@ -452,7 +452,7 @@ English:This is the identifier used in the gcode to specify the extruder.
Translated:Ten identyfikator jest wykorzystywany w gcode do wskazania ekstrudera.
English:All extrusions are multiplied by this value. Increasing it above 1 (1.1 is a good max value) will increase the amount of filament being extruded; decreasing it (.9 is a good min value) will decrease the amount being extruded.
-Translated:Wszystkie profile są mnożone przez tę wartość. Zwiększenie jej powyżej 1 (max 1.1) zwiększy ilość materiału ekstrudowanego; zmniejszenie zaś (min 0.9) - zmniejszy ilość materiału ekstrudowanego.
+Translated:Wszystkie ekstrudowania są mnożone przez tę wartość. Zwiększenie jej powyżej 1 (max 1.1) zwiększy ilość materiału ekstrudowanego; zmniejszenie zaś (min 0.9) - zmniejszy ilość materiału ekstrudowanego.
English:Leave this as 0 to allow automatic calculation of extrusion width.
Translated:Ustaw wartość 0, aby umożliwić automatyczne obliczanie szerokości ekstrudowania.
@@ -1073,7 +1073,7 @@ English:Disable Fan For The First
Translated:Wyłączenie wentylatora dla 1-szej warstwy
English:Fan Speed
-Translated:Predkośc wentylatora
+Translated:Predkość wentylatora
English:Slow Down If Layer Print\nTime Is Below
Translated:Zwolnij, jesli dla 1-szej warstwy\nczas jest poniżej
@@ -2291,10 +2291,10 @@ English:Title Stuff
Translated:Nazwa materiału
English:Oops! You cannot exit while a print is active.
-Translated:Ups! Nie możesz wyjśc w czasie drukowania.
+Translated:Ups! Nie możesz wyjść w czasie drukowania.
English:Unable to Exit
-Translated:Wyjście niemozliwe
+Translated:Wyjście niemożliwe
English:You are currently saving a parts sheet, are you sure you want to exit?
Translated:Aktualnie jest zapisywany arkusz elementów, czy na pewno chcesz wyjść ?
@@ -2351,7 +2351,7 @@ English:Sample the bed at two points
Translated:Próbkuj stolik w dwóch punktach
English:You should be done in about 2 minutes.
-Translated:POwinienes móc to zrobić w około 2 minuty.
+Translated:Powinieneś móc to zrobić w około 2 minuty.
English:Alert
Translated:Alarm
@@ -2486,19 +2486,19 @@ English:Release Notes
Translated:Informacje o wydaniu
English:More Info
-Translated:More Info
+Translated:Więcej info
English:Go To Status
-Translated:Go To Status
+Translated:Określ status
English:View Status
-Translated:View Status
+Translated:Pokaż status
English:Description
-Translated:Description
+Translated:Opis
English:Value
-Translated:Value
+Translated:Wartość
English:Save To EEPROM
Translated:Zapisz do EEPROM
@@ -2570,79 +2570,79 @@ English:Select an Image
Translated:Wybierz obraz
English:If greater than 0, this is the X by Y size of a tower to use to when changing extruders
-Translated:If greater than 0, this is the X by Y size of a tower to use to when changing extruders
+Translated:Jeżeli większe niż 0, to jest od wielkości X Y wieży wymagana podczas zmiany ekstrudera
English:Extruder Change
-Translated:Extruder Change
+Translated:Zmiana ekstrudera
English:Wipe Tower Size
-Translated:Wipe Tower Size
+Translated:Rozmiar wieży otarcia
English:Sorry, we were unable to install the driver.
-Translated:Sorry, we were unable to install the driver.
+Translated:Niestety, nie udało się zainstalować sterownika.
English:Tuning Adjustment
-Translated:Tuning Adjustment
+Translated:Regulacja dostrajania
English:Release
Translated:Release
English:No printer is currently selected. Select a printer to edit slice settings.
-Translated:No printer is currently selected. Select a printer to edit slice settings.
+Translated:Drukarka nie jest aktualnie wybrana. Wybierz, aby edytować ustawienia Slice.
English:Part Preview
-Translated:Part Preview
+Translated:Podgląd elementu
English:Layer Preview
-Translated:Layer Preview
+Translated:Podgląd warstwy
English:Enable Cloud Monitoring (disabled)
-Translated:Enable Cloud Monitoring (disabled)
+Translated:Uruchamia Cloud Monitoring (wyłączony)
English:Warning - Moving Too Low
-Translated:Warning - Moving Too Low
+Translated:Ostrzeżenie - ruch zbyt nisko
English:Oops! Could not find this file:
-Translated:Oops! Could not find this file:
+Translated:Ups! Nie znaleziono pliku:
English:The number of extruders this machine has.
-Translated:The number of extruders this machine has.
+Translated:Ilość ekstruderów dostepnych w tej drukarce.
English:All extrusions are multiplied by this value. Increasing it above 1 (1.1 is a good max value) will increase the amount of filament being extruded; decreasing it (.9 is a good minimum value) will decrease the amount being extruded.
-Translated:All extrusions are multiplied by this value. Increasing it above 1 (1.1 is a good max value) will increase the amount of filament being extruded; decreasing it (.9 is a good minimum value) will decrease the amount being extruded.
+Translated:Wszystkie ekstrudowania są mnożone przez tę wartość. Zwiększenie jej powyżej 1 (max 1.1) zwiększy ilość materiału ekstrudowanego; zmniejszenie zaś (min 0.9) - zmniejszy ilość materiału ekstrudowanego.
English:This is the minimum speed that the printer will reduce to to make the layer take long enough to satisfy the minimum layer time.
-Translated:This is the minimum speed that the printer will reduce to to make the layer take long enough to satisfy the minimum layer time.
+Translated:To jest minimalna prędkość do jakiej drukarka zwolni, by wydruk warstwy trwał wystarczająco długo spełniając wymóg ustawienia minimalnego czasu drukowania warstwy..
English:Minimum Print Speed
-Translated:Minimum Print Speed
+Translated:Minimalna prędkośc druku
English:Skirt and Raft
-Translated:Skirt and Raft
+Translated:Elementy 'Skirt' i 'Raft'
English:Length on Move
-Translated:Length on Move
+Translated:Długość na ruch
English:Length on Tool Change
-Translated:Length on Tool Change
+Translated:Długość na zmianę narzędzia
English:Minimum Extrusion\nRequiring Retraction
-Translated:Minimum Extrusion\nRequiring Retraction
+Translated:Minimalne ekstrudowanie\nwymagające retrakcji
English:Minimum Fan Speed
-Translated:Minimum Fan Speed
+Translated:Minimalna prędkośc wentylatora
English:Extruder Count
-Translated:Extruder Count
+Translated:Numer ekstrudera
English:Hardware
Translated:Hardware
English:Search Library
-Translated:Search Library
+Translated:Przeszukaj bibliotekę
English:My Library
-Translated:My Library
+Translated:Moja Biblioteka
English:Jakość
Translated:Jakość
@@ -2651,5 +2651,5 @@ English:Materiał
Translated:Materiał
English:Extruder Temperature Override
-Translated:Extruder Temperature Override
+Translated:Przekroczona temperatura ekstrudera
diff --git a/StaticData/Translations/pl/readme.txt b/StaticData/Translations/pl/readme.txt
index 498add1f4..bd0dc7326 100644
--- a/StaticData/Translations/pl/readme.txt
+++ b/StaticData/Translations/pl/readme.txt
@@ -1,3 +1,3 @@
-This folder contains the Japanese translation. The
+This folder contains the Polish translation. The
es comes from the ISO 639 standard which can be found at:
http://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
\ No newline at end of file
diff --git a/PrinterControls/PrinterConnections/SetupStepInstallDriver.cs b/PrinterControls/PrinterConnections/SetupStepInstallDriver.cs
index 1f58421a0..d7084d702 100644
--- a/PrinterControls/PrinterConnections/SetupStepInstallDriver.cs
+++ b/PrinterControls/PrinterConnections/SetupStepInstallDriver.cs
@@ -1,10 +1,12 @@
using System;
+using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using MatterHackers.Agg;
using MatterHackers.Agg.PlatformAbstract;
using MatterHackers.Agg.UI;
using MatterHackers.Localizations;
+using MatterHackers.MatterControl.DataStorage;
namespace MatterHackers.MatterControl.PrinterControls.PrinterConnections
{
@@ -114,23 +116,29 @@ namespace MatterHackers.MatterControl.PrinterControls.PrinterConnections
var driverInstallerProcess = new Process();
// Prepare the process to run
// Enter in the command line arguments, everything you would enter after the executable name itself
- driverInstallerProcess.StartInfo.Arguments = Path.GetFullPath(fileName);
- // Enter the executable to run, including the complete path
- string printerDriverInstallerExePathAndFileName = Path.Combine(".", "InfInstaller.exe");
+ driverInstallerProcess.StartInfo.Arguments = "/a {0}".FormatWith(Path.GetFullPath(fileName));
driverInstallerProcess.StartInfo.CreateNoWindow = true;
driverInstallerProcess.StartInfo.WindowStyle = ProcessWindowStyle.Hidden;
- driverInstallerProcess.StartInfo.FileName = Path.GetFullPath(printerDriverInstallerExePathAndFileName);
- driverInstallerProcess.StartInfo.Verb = "runas";
- driverInstallerProcess.StartInfo.UseShellExecute = true;
+ string pnpUtilFileName = "PnPUtil.exe";
+ // find the location of pnputil.exe
+ List files = new List(Directory.GetFiles("C:/Windows/winsxs", pnpUtilFileName, SearchOption.AllDirectories));
- driverInstallerProcess.Start();
+ if(files.Count > 0)
+ {
+ string pathToPnPUtil = files[0];
+ driverInstallerProcess.StartInfo.FileName = Path.Combine(pathToPnPUtil);
+ driverInstallerProcess.StartInfo.Verb = "runas";
+ driverInstallerProcess.StartInfo.UseShellExecute = true;
- driverInstallerProcess.WaitForExit();
+ driverInstallerProcess.Start();
- // Retrieve the app's exit code
- var exitCode = driverInstallerProcess.ExitCode;
+ driverInstallerProcess.WaitForExit();
+
+ // Retrieve the app's exit code
+ var exitCode = driverInstallerProcess.ExitCode;
+ }
}
else
{
@@ -196,7 +204,7 @@ namespace MatterHackers.MatterControl.PrinterControls.PrinterConnections
InstallDriver(this.printerDriverFilePath);
return true;
}
- catch
+ catch(Exception)
{
printerDriverMessage.Text = LocalizedString.Get("Sorry, we were unable to install the driver.");
return false;